package Bundle::Locale::CLDR::World;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::World

=head1 CONTENTS

Bundle::Locale::CLDR::Asia 0.34.1
Bundle::Locale::CLDR::Africa 0.34.1
Bundle::Locale::CLDR::Europe 0.34.1
Bundle::Locale::CLDR::Oceania 0.34.1
Bundle::Locale::CLDR::Americas 0.34.1
Bundle::Locale::CLDR::Eurozone 0.34.1
Bundle::Locale::CLDR::Europeanunion 0.34.1
Bundle::Locale::CLDR::Unitednations 0.34.1

=cut

1;

